==> elgg-1.11.0.zip: elgg-1.11.0/mod/messages/languages/da.php <==
<?php
return array(
	/**
	* Menu items and titles
	*/

	'messages' => "Beskeder",
	'messages:unreadcount' => "%s unread",
	'messages:back' => "Tilbage til beskeder",
	'messages:user' => "%s's indbakke",
	'messages:posttitle' => "%s's beskeder: %s",
	'messages:inbox' => "Indbakke",
	'messages:sent' => "Sendte beskeder",
	'messages:message' => "Besked",
	'messages:title' => "Emne",
	'messages:to:help' => "Write recipient's username here.",
	'messages:replying' => "Besked som svar til",
	'messages:inbox' => "Indbakke",
	'messages:sendmessage' => "Send en besked",
	'messages:add' => "Opret en besked",
	'messages:sentmessages' => "Sendte beskeder",
	'messages:recent' => "Seneste beskeder",
	'messages:original' => "Original besked",
	'messages:yours' => "Din besked",
	'messages:toggle' => 'Marker alle',
	'messages:markread' => 'Marker som læst',
	'messages:recipient' => 'Vælg en modtager&hellip;',
	'messages:to_user' => 'To: %s',

	'messages:new' => 'Ny besked',

	'notification:method:site' => 'Beskeder',

	'messages:error' => 'Der opstod et problem med at gemme din besked. Prøv venligst igen.',

	'item:object:messages' => 'Beskeder',

	/**
	* Status messages
	*/

	'messages:posted' => "Din besked blev sendt.",
	'messages:success:delete:single' => 'Din besked blev slettet.',
	'messages:success:delete' => 'Dine beskeder blev slettet.',
	'messages:success:read' => 'Beskeder markeret som læst',
	'messages:error:messages_not_selected' => 'Ingen beskeder valgt',
	'messages:error:delete:single' => 'Kunne ikke slette beskeden',

	/**
	* Email messages
	*/

	'messages:email:subject' => 'Du har en ny besked!',
	'messages:email:body' => "Du har fået en ny besked fra %s. De indeholder:


%s


For at se dine besked, så skal du klikke her:

%s

For at sende %s en besked, så skal du klikke her:

%s

Være venlig ikke at svare på denne email.",

	/**
	* Error messages
	*/

	'messages:blank' => "Beklager, du skal skrive noget i beskedfeltet, før den kan gemmes.",
	'messages:notfound' => "Beklager, vi kunne ikke finde den specificerede besked.",
	'messages:notdeleted' => "Beklager, beskeden kunne ikke slettes.",
	'messages:nopermission' => "Du har ikke tilladelse til at ændre beskeden.",
	'messages:nomessages' => "Der er ingen beskeder at vise.",
	'messages:user:nonexist' => "Modtageren kunne ikke findes i databasen.",
	'messages:user:blank' => "Du har ikke valgt nogen at sende til.",
	'messages:user:self' => "Du kan ikke sende en besked til dig selv.",

	'messages:deleted_sender' => 'Slettet bruger',

);

==> elgg-1.12.16.zip: elgg-1.12.16/mod/messages/languages/da.php <==
<?php
return array(
	/**
	* Menu items and titles
	*/

	'messages' => "Beskeder",
	'messages:unreadcount' => "%s unread",
	'messages:back' => "back to messages",
	'messages:user' => "%s's indbakke",
	'messages:posttitle' => "%s's beskeder: %s",
	'messages:inbox' => "Indbakke",
	'messages:sent' => "Sendte beskeder",
	'messages:message' => "Besked",
	'messages:title' => "Emne",
	'messages:to:help' => "Write recipient's username here.",
	'messages:replying' => "Besked som svar til",
	'messages:sendmessage' => "Send en besked",
	'messages:add' => "Opret en besked",
	'messages:sentmessages' => "Sendte beskeder",
	'messages:recent' => "Seneste beskeder",
	'messages:original' => "Original besked",
	'messages:yours' => "Din besked",
	'messages:toggle' => 'Marker alle',
	'messages:markread' => 'Marker som læst',
	'messages:recipient' => 'Vælg en modtager&hellip;',
	'messages:to_user' => 'To: %s',

	'messages:new' => 'Ny besked',

	'notification:method:site' => 'Beskeder',

	'messages:error' => 'Der opstod et problem med at gemme din besked. Prøv venligst igen.',

	'item:object:messages' => 'Beskeder',

	/**
	* Status messages
	*/

	'messages:posted' => "Din besked blev sendt.",
	'messages:success:delete:single' => 'Din besked blev slettet.',
	'messages:success:delete' => 'Dine beskeder blev slettet.',
	'messages:success:read' => 'Beskeder markeret som læst',
	'messages:error:messages_not_selected' => 'Ingen beskeder valgt',
	'messages:error:delete:single' => 'Kunne ikke slette beskeden',

	/**
	* Email messages
	*/

	'messages:email:subject' => 'Du har en ny besked!',
	'messages:email:body' => "Du har fået en ny besked fra %s. De indeholder:


%s


For at se dine besked, så skal du klikke her:

%s

For at sende %s en besked, så skal du klikke her:

%s

Være venlig ikke at svare på denne email.",

	/**
	* Error messages
	*/

	'messages:blank' => "Beklager, du skal skrive noget i beskedfeltet, før den kan gemmes.",
	'messages:notfound' => "Beklager, vi kunne ikke finde den specificerede besked.",
	'messages:notdeleted' => "Beklager, beskeden kunne ikke slettes.",
	'messages:nopermission' => "Du har ikke tilladelse til at ændre beskeden.",
	'messages:nomessages' => "Der er ingen beskeder at vise.",
	'messages:user:nonexist' => "Modtageren kunne ikke findes i databasen.",
	'messages:user:blank' => "Du har ikke valgt nogen at sende til.",
	'messages:user:self' => "Du kan ikke sende en besked til dig selv.",

	'messages:deleted_sender' => 'Slettet bruger',

);
